@@ -5,9 +5,16 @@ use warnings;
 use base qw( Alien::Base );
 
 # ABSTRACT: Find or build m4
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 
+sub alien_helper
+{
+  return {
+    m4 => sub { 'm4' },
+  };
+}
+
 1;
 
 __END__
@@ -22,7 +29,7 @@ Alien::m4 - Find or build m4
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -46,13 +53,21 @@ From Alien::Base Build.PL
 
 This package can be used by other CPAN modules that require m4.
 
+=head1 HELPERS
+
+=head2 m4
+
+ %{m4}
+
+Returns the name of the m4 command.  Usually just C<m4>.
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
